#!/bin/sh
#2017/05/05 by verysync
#version 0.2

export KSROOT=/koolshare
source $KSROOT/scripts/base.sh
eval `dbus export verysync_`

export HOME=/root

create_conf(){
    if [ ! -d $verysync_home ];then
        $KSROOT/verysync/verysync -generate="$verysync_home/.verysync" >>/tmp/verysync.log
    fi
}

lan_ip=$(uci get network.lan.ipaddr)
weburl="http://$lan_ip:$verysync_port"

get_ipaddr(){
    if [ $verysync_wan_enable == 1 ];then
        ipaddr="0.0.0.0:$verysync_port"
    else
        ipaddr="$lan_ip:$verysync_port"
    fi
    #sed -i "/<gui enabled/{n;s/[0-9.]\{7,15\}:[0-9]\{2,5\}/$ipaddr/g}" $conf_Path/config.xml
}

setup_iptables() {
	local ports="tcp:$verysync_port tcp:22330 udp:22331"
	for item in $ports; do
		local proto=${item%:*}
		local port=${item#*:}
		local rule="INPUT -p $proto --dport $port -j ACCEPT"
		if ! iptables -C $rule >/dev/null; then
			iptables -I $rule
		fi
	done
}

setup_optimize() {
    echo 204800 > /proc/sys/fs/inotify/max_user_watches

    #setup_swap
}

setup_swap() {
    local swapfile="$verysync_home/.verysync/swapfile"
    if [[ ! -f "$swapfile" -a "$verysync_swap_enable" == "1" ]]; then
        dd if=/dev/zero of="$swapfile" count=512 bs=1M
        chmod 600 "$swapfile"
        mkswap "$swapfile"
    fi

    if [[ -f "$swapfile" ]]; then
        swapon "$swapfile"
    fi
}

start_verysync(){
    export GOGC=30

    setup_iptables
    setup_optimize

    dbus set verysync_version=`/koolshare/verysync/verysync -version|awk '{print $2}'`

    VSNORESTART=""
    if [[ "$verysync_swap_enable" != "1" ]]; then
        VSNORESTART=" -no-restart"
    fi

    $KSROOT/verysync/verysync -home="$verysync_home/.verysync" -gui-address $ipaddr $VSNORESTART >/dev/null 2>&1 &
    #cru d verysync
    #cru a verysync "*/1 * * * * sh $KSROOT/scripts/verysync_config.sh"

	sleep 1
    dbus set verysync_webui=$weburl

    ln -sf $KSROOT/init.d/S97verysync.sh /etc/rc.d/S97verysync.sh
}

stop_verysync(){
    for i in `ps |grep verysync|grep -v grep|grep -v "/bin/sh"|awk -F' ' '{print $1}'`;do
        kill $i
    done
    sleep 2
    #cru d verysync

    dbus set verysync_webui="-"
}

update_disklist() {
    dbus set verysync_disklist=`df -h | grep mnt| awk '{print $6"\t"$4}'|openssl base64`
}

case $ACTION in
start)
    update_disklist
    if [ "$verysync_home" = "" ]; then
        http_response "微力同步: 您还未设置应用数据目录"
        exit 1
    fi
    mkdir -p "$verysync_home/.verysync"
    if [[ $? -ne 0 ]]; then
        http_response "[软件中心]: 微力同步 您设置的应用数据目录${verysync_home}/.verysync 无法创建，请检查路径的有效性"
        exit 1
    fi

	if [ "$verysync_enable" = "1" ]; then
		http_response "[软件中心]: 启动微力同步"
		create_conf
		get_ipaddr
		start_verysync
	else
		update_disklist
		http_response "[软件中心]: 微力同步未设置开启,跳过！"
	fi
	;;
stop)
	update_disklist
	stop_verysync
	;;
*)
	update_disklist
    if [ "$verysync_enable" = "1" ]; then
        if [ "`ps|grep verysync|grep -v "/bin/sh"|grep -v grep|wc -l`" != "0" ];then 
            stop_verysync
        fi
        create_conf
        get_ipaddr
        start_verysync
	else
        stop_verysync
    fi
    http_response '设置已保存！切勿重复提交！页面将在3秒后刷新'
	;;
esac
